The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Type: Package
Title: Search Engine Optimization and Social Metadata Helpers for 'Shiny' Apps
Version: 0.1.0
Author: Rolf Lindgren [aut, cre]
Maintainer: Rolf Lindgren <rolf@grendel.no>
Description: Utilities for injecting search engine optimization (SEO), Open Graph, Twitter, and schema.org metadata into 'Shiny' applications from YAML files or named lists.
License: GPL (≥ 3)
Encoding: UTF-8
Imports: shiny, yaml, jsonlite
Suggests: htmltools, knitr, rmarkdown, testthat (≥ 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-29 07:50:52 UTC; roffe
Repository: CRAN
Date/Publication: 2026-04-29 19:10:03 UTC

Inject social metadata into Shiny UI

Description

Inject social metadata into Shiny UI

Usage

social_meta(meta)

Arguments

meta

Either a path to a YAML file or a named list. The final metadata must include title, description, url, and image.

Details

If meta is a character string, it is treated as a YAML file path and read with yaml::read_yaml(). Set schema = FALSE to suppress JSON-LD output. Optional verification fields include bing_site_verification and google_site_verification.

Value

A shiny::tags$head() fragment containing canonical, Open Graph, Twitter Card, and optional schema.org metadata.

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.